Structs
Enums
Carries the logic of how scale adjustment to the mapping should be done.
Tight means the two scales will extend just enough to show the data.
Round means the scales will extend to show the data, and a little
more so that it ends at a nearby round number at the scale of 5 or 10.
Off means adjustment is not applied, and the minimum and maximum
values supplied by the user will be used instead.